@@ -2,7 +2,7 @@ import json
 
 import pandas as pd
 
-tasks = pd.read_json("webvoyager.jsonl", lines=True)  # type: ignore
+tasks = pd.read_json("webvoyager.jsonl", lines=True)
 
 with open("answers.json", "r") as f:
     answers = json.load(f)
